==> openmolcas_19.11.orig.tar.gz: OpenMolcas-v19.11/src/integral_util/inisew.f <==
************************************************************************
* This file is part of OpenMolcas.                                     *
*                                                                      *
* OpenMolcas is free software; you can redistribute it and/or modify   *
* it under the terms of the GNU Lesser General Public License, v. 2.1. *
* OpenMolcas is distributed in the hope that it will be useful, but it *
* is provided "as is" and without any express or implied warranties.   *
* For more details see the full text of the license in the file        *
* LICENSE or in <http://www.gnu.org/licenses/>.                        *
*                                                                      *
* Copyright (C) 1999, Roland Lindh                                     *
************************************************************************
      SubRoutine IniSew(Info,DSCF,nDiff)
************************************************************************
*                                                                      *
* Object:                                                              *
*                                                                      *
* Called from:                                                         *
*                                                                      *
* Calling    : QEnter                                                  *
*              QExit                                                   *
*                                                                      *
*     Author: Roland Lindh, Dept. of Chemical Physics,                 *
*             University of Lund, SWEDEN                               *
************************************************************************
      Implicit Real*8 (A-H,O-Z)
#include "SysDef.fh"
#include "itmax.fh"
#include "info.fh"
#include "nsd.fh"
#include "setup.fh"
#include "WrkSpc.fh"
#include "status.fh"
#include "print.fh"
*
      Logical DSCF
*
      If (Seward_Status.eq.Active) Then
         Call ClsSew()
         Call xRlsMem_Ints()
      End If
*
      Call Seward_Init
*
      Call GetInf(Info,nInfo,DSCF,nDiff,1)
*
      Return
      End

==> openmolcas_23.10.orig.tar.gz: OpenMolcas-v23.10/src/integral_util/inisew.f <==
************************************************************************
* This file is part of OpenMolcas.                                     *
*                                                                      *
* OpenMolcas is free software; you can redistribute it and/or modify   *
* it under the terms of the GNU Lesser General Public License, v. 2.1. *
* OpenMolcas is distributed in the hope that it will be useful, but it *
* is provided "as is" and without any express or implied warranties.   *
* For more details see the full text of the license in the file        *
* LICENSE or in <http://www.gnu.org/licenses/>.                        *
*                                                                      *
* Copyright (C) 1999, Roland Lindh                                     *
************************************************************************
      SubRoutine IniSew(DSCF,nDiff)
************************************************************************
*     Author: Roland Lindh, Dept. of Chemical Physics,                 *
*             University of Lund, SWEDEN                               *
************************************************************************
      Implicit Real*8 (A-H,O-Z)
#include "SysDef.fh"
#include "nsd.fh"
#include "setup.fh"
#include "status.fh"
*
      Logical DSCF
*
      If (Seward_Status.eq.Active) Then
         Call ClsSew()
         Call xRlsMem_Ints()
      End If
*
      Call Seward_Init()
*
      Call GetInf(DSCF,nDiff)
*
      Return
      End
